@@ -132,7 +132,7 @@ sub install_port {
 		my $path = "/usr/ports/$category/$port_dir";
 		-d $path && chdir $path or croak "couldn't cd to $path: $!\n";
 
-    $log->audit("install_port: installing $portname");
+    $util->audit("install_port: installing $portname");
 
     # these are the "make -DWITH_OPTION" flags
     if ( $p{flags} ) {
@@ -169,7 +169,7 @@ sub install_port {
 
     return 1 if $self->is_port_installed( $check, debug=>1 );
 
-    $log->audit( "install_port: $portname install, FAILED" );
+    $util->audit( "install_port: $portname install, FAILED" );
     $self->install_port_try_manual( $portname, $path );
 
     if ( $portname =~ /\Ap5\-(.*)\z/ ) {
@@ -199,24 +199,37 @@ sub is_port_installed {
 
     my $alt = $p{'alt'} || $port;
 
+    my $conf = $toaster->get_config;
+    my $pkg_method = $conf->{'use_pkgng'} || 0;
+
+
     my ( $r, @args );
 
-    $log->audit( "  checking for port $port", debug=>0);
+    $util->audit( "  checking for port $port", debug=>0);
 
     return $p{'test_ok'} if defined $p{'test_ok'};
 
-    my $pkg_info = $util->find_bin( 'pkg_info', debug => 0 );
-    my @packages = `pkg_info`; chomp @packages;
+    my @packages;
+    my $pkg_info;
+    if ( $pkg_method == 0) { 
+        $pkg_info = $util->find_bin( 'pkg_info', debug => 0 );
+        @packages = `pkg_info`; chomp @packages;
+    }
+    else{ 
+        $pkg_info = $util->find_bin( 'pkg', debug => 0 );
+        @packages = `pkg info`; chomp @packages;
+    } 
+    
     my @matches = grep {/^$port\-/} @packages;
     if ( scalar @matches == 0 ) { @matches = grep {/^$port/} @packages; };
     if ( scalar @matches == 0 ) { @matches = grep {/^$alt\-/ } @packages; };
     if ( scalar @matches == 0 ) { @matches = grep {/^$alt/ } @packages; };
     return if scalar @matches == 0; # no matches
-    $toaster->audit( "WARN: found multiple matches for port $port",debug=>1)
+    $util->audit( "WARN: found multiple matches for port $port",debug=>1)
         if scalar @matches > 1;
 
     my ($installed_as) = split(/\s/, $matches[0]);
-    $toaster->audit( "found port $port installed as $installed_as",debug=>$p{debug} );
+    $util->audit( "found port $port installed as $installed_as",debug=>$p{debug} );
     return $installed_as;
 }
 
@@ -265,10 +278,13 @@ sub install_package {
 
     my ( $alt, $pkg_url ) = ( $p{'alt'}, $p{'url'} );
     my %args = $toaster->get_std_args( %p );
+    
+    my $conf = $toaster->get_config;
+    my $pkg_method = $conf->{'use_pkgng'} || 0;
 
     return $util->error("sorry, but I really need a package name!") if !$package;
 
-    $log->audit("install_package: checking if $package is installed");
+    $util->audit("install_package: checking if $package is installed");
 
     return $p{'test_ok'} if defined $p{'test_ok'};
 
@@ -277,11 +293,24 @@ sub install_package {
     print "install_package: installing $package....\n";
     $ENV{"PACKAGESITE"} = $pkg_url if $pkg_url;
 
-    my $pkg_add = $util->find_bin( "pkg_add", %args );
+    my $pkg_add;
+    if ( $pkg_method == 0) { 
+        $pkg_add = $util->find_bin( "pkg_add", %args );
+    } else { 
+        $pkg_add = $util->find_bin( "pkg", %args );
+    }
+
+    
+    
     return $log->error( "couldn't find pkg_add, giving up.",fatal=>0)
         if ( !$pkg_add || !-x $pkg_add );
 
-    my $r2 = $util->syscmd( "$pkg_add -r $package", debug => 0 );
+    my $r2;
+    if ( $pkg_method == 0) {    
+        $r2 = $util->syscmd( "$pkg_add -r $package", debug => 0 );
+    } else {
+        $r2 = $util->syscmd( "$pkg_add add -r $package", debug => 0 );
+    }
 
     if   ( !$r2 ) { print "\t pkg_add failed\t "; }
     else          { print "\t pkg_add success\t " };
@@ -289,17 +318,30 @@ sub install_package {
     unless ( $self->is_port_installed( $package, alt => $alt, %args )) {
         print "Failure #1, trying alternate package site.\n";
         $ENV{"PACKAGEROOT"} = "ftp://ftp2.freebsd.org";
-        $util->syscmd( "$pkg_add -r $package", debug => 0 );
+        if ( $pkg_method == 0) {    
+            $util->syscmd( "$pkg_add -r $package", debug => 0 );
+        } else {
+            $util->syscmd( "$pkg_add add -r $package", debug => 0 );
+        }
+
 
         unless ( $self->is_port_installed( $package, alt => $alt, %args,)) {
             print "Failure #2, trying alternate package site.\n";
             $ENV{"PACKAGEROOT"} = "ftp://ftp3.freebsd.org";
-            $util->syscmd( "$pkg_add -r $package", debug => 0 );
+            if ( $pkg_method == 0) {    
+                $util->syscmd( "$pkg_add -r $package", debug => 0 );
+            } else {
+                $util->syscmd( "$pkg_add add -r $package", debug => 0 );
+            }
 
             unless ( $self->is_port_installed( $package, alt => $alt, %args,)) {
                 print "Failure #3, trying alternate package site.\n";
                 $ENV{"PACKAGEROOT"} = "ftp://ftp4.freebsd.org";
-                $util->syscmd( "$pkg_add -r $package", debug => 0 );
+                if ( $pkg_method == 0) {    
+                    $util->syscmd( "$pkg_add -r $package", debug => 0 );
+                } else {
+                    $util->syscmd( "$pkg_add add -r $package", debug => 0 );
+                }
             }
         }
     }
@@ -449,7 +491,7 @@ sub conf_check {
     my $check = $p{check};
     my $line  = $p{line};
     my $file  = $p{file} || "/etc/rc.conf";
-    $log->audit("conf_check: looking for $check");
+    $util->audit("conf_check: looking for $check");
 
     return $p{'test_ok'} if defined $p{'test_ok'};
 
@@ -458,8 +500,8 @@ sub conf_check {
     @lines = $util->file_read( $file ) if -f $file;
     foreach ( @lines ) {
         next if $_ !~ /^$check\=/;
-        return $log->audit("\tno change") if $_ eq $line;
-        $log->audit("\tchanged:\n$_\n\tto:\n$line\n" );
+        return $util->audit("\tno change") if $_ eq $line;
+        $util->audit("\tchanged:\n$_\n\tto:\n$line\n" );
         $_ = $line;
         $changes++;
     };
